complete -c listenbrainz-mpd -s c -l config -d 'Path to the configuration file' -r -F
complete -c listenbrainz-mpd -l send-feedback -d 'Submit feedback for the currently playing song and exit' -r -f -a "hate\t''
clear\t''
love\t''"
complete -c listenbrainz-mpd -l create-default-config -d 'Create a configuration file in the default location and exit'
complete -c listenbrainz-mpd -s h -l help -d 'Print help'
complete -c listenbrainz-mpd -s V -l version -d 'Print version'
